<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['%d association'] = "%d association";
$lang['%d associations'] = "%d associations";
$lang['%d album including'] = "%d catégorie dont";
$lang['%d albums including'] = "%d catégories dont";
$lang['%d physical'] = " %d physique";
$lang['%d physical'] = " %d physiques";
$lang[' and %d virtual'] = " et %d virtuelle";
$lang[' and %d virtual'] = " et %d virtuelles";
$lang['%d album moved'] = "%d catégorie déplacée";
$lang['%d albums moved'] = "%d catégories déplacées";
$lang['%d group'] = "%d groupe";
$lang['%d groups'] = "%d groupes";
$lang['%d member'] = "%d membre";
$lang['%d members'] = "%d membres";
$lang['%d tag'] = "%d mot clé";
$lang['%d tags'] = "%d mots clés";
$lang['%d user comment rejected'] = "%d commentaire d'utilisateur rejeté";
$lang['%d user comments rejected'] = "%d commentaires d'utilisateurs rejetés";
$lang['%d user comment validated'] = "%d commentaire d'utilisateur validé";
$lang['%d user comments validated'] = "%d commentaires d'utilisateurs validés";
$lang['%d user deleted'] = "%d utilisateur supprimé";
$lang['%d users deleted'] = "%d utilisateurs supprimés";
$lang['%d user'] = "%d utilisateur";
$lang['%d users'] = "%d utilisateurs";
$lang['%d waiting for validation'] = "%d en attente de validation";
$lang['Actions'] = "Actions";
$lang['Activate'] = "Activer";
$lang['Add/delete a permalink'] = "Ajouter/effacer un lien permanent";
$lang['Add a tag'] = "Ajouter un mot clé";
$lang['Add a user'] = "Ajouter un utilisateur";
$lang['Add group'] = "Ajouter un groupe";
$lang['Add'] = "Ajouter";
$lang['Allow user registration'] = "Permettre l'enregistrement des utilisateurs";
$lang['Apply to sub-albums'] = "Appliquer aux sous-catégories";
$lang['Associated'] = "Associée à";
$lang['Batch management'] = "Gestion par lot";
$lang['Caddie management'] = "Gestion du panier";
$lang['Caddie'] = "Panier";
$lang['Albums authorized thanks to group associations'] = "Catégories accessibles grâce à l'appartenance aux groupes";
$lang['Album manual order was saved'] = "L'ordre manuel des catégories a été sauvegardé";
$lang['Check for upgrade failed for unknown reasons.'] = "La vérification de la dernière version sur le serveur a échouée pour une raison inconnue.";
$lang['Check for upgrade'] = "Dernière version ?";
$lang['Comments for all'] = "Commentaires pour tous";
$lang['Current name'] = "Nom courant";
$lang['Database'] = "Base de données";
$lang['Deactivate'] = "Désactiver";
$lang['Delete Representant'] = "Supprimer le représentant";
$lang['Delete selected tags'] = "Supprimer les mots clés sélectionnés";
$lang['Delete selected users'] = "Supprimer les utilisateurs sélectionnés";
$lang['Deletions'] = "Suppressions";
$lang['Deny selected groups'] = "Interdire l'accès aux groupes sélectionnés";
$lang['Deny selected users'] = "Interdire l'accès aux utilisateurs sélectionnés";
$lang['Description'] = "Description";
$lang['Display options'] = "Options d'affichage";
$lang['Dissociated'] = "Dissociée de";
$lang['Does not represent'] = "Ne représente pas";
$lang['Edit selected tags'] = "Éditer les mots clés sélectionnés";
$lang['Edit tags'] = "Éditer les mots clés";
$lang['Email admins when a new user registers'] = "Notifier les administrateurs lors de l'inscription d'un utilisateur";
$lang['Email admins when a valid comment is entered'] = "Notifier les administrateurs quand un commentaire est enregistré";
$lang['Email admins when a comment requires validation'] = "Notifier les administrateurs quand un commentaire requiert leur validation";
$lang['Environment'] = "Environnement";
$lang['Form'] = "Formulaire";
$lang['Gallery title'] = "Titre de la galerie";
$lang['Grant selected groups'] = "Donner l'accès aux groupes sélectionnés";
$lang['Grant selected users'] = "Donner l'accès aux utilisateurs sélectionnés";
$lang['Group name'] = "Nom du groupe";
$lang['Groups'] = "Groupes";
$lang['Guests'] = "Invités";
$lang['History'] = "Historique";
$lang['Informations'] = "Informations";
$lang['Install'] = "Installer";
$lang['Link all album photos to a new album'] = "Associer tous les éléments de la catégorie à une nouvelle catégorie";
$lang['Link all album photos to some existing albums'] = "Associer tous les éléments de la catégorie à des catégories existantes";
$lang['Linked albums'] = "Catégories associées";
$lang['Lock gallery'] = "Verrouiller la galerie";
$lang['Maintenance'] = "Maintenance";
$lang['Edit album permissions'] = "Gérer les permissions pour une catégorie";
$lang['Manage permissions for group "%s"'] = "Gérer les permissions pour le groupe \"%s\"";
$lang['Manage permissions for user "%s"'] = "Gérer les permissions pour l'utilisateur \"%s\"";
$lang['Manage tags'] = "Gérer les mots clés";
$lang['Members'] = "Membres";
$lang['Metadata synchronized from file'] = "Méta-données synchronisées à partir du fichier";
$lang['Move albums'] = "Déplacer les catégories";
$lang['Move'] = "Déplacer";
$lang['Name'] = "Nom";
$lang['New name'] = "Nouveau nom";
$lang['New parent album'] = "Nouvelle catégorie parente";
$lang['New tag'] = "Nouveau mot clé";
$lang['Number of comments per page'] = "Nombre de commentaires par page";
$lang['Number of rates'] = "Nombre de notes";
$lang['Number of thumbnails to create'] = "Nombre de miniatures à créer";
$lang['Only private albums are listed'] = "Seules les catégories privées sont listées";
$lang['Operating system'] = "Système d'exploitation";
$lang['Options'] = "Options";
$lang['Other private albums'] = "Autres catégories privées";
$lang['Page banner'] = "Bannière des pages";
$lang['Parent album'] = "Catégorie parente";
$lang['Path'] = "Chemin";
$lang['Permalink'] = "Lien permanent";
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = "Le lien permanent %s a été précédemment utilisé par la catégorie %s. Veuillez l'effacer de l'historique des liens permanents";
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = "Le lien permanent ne doit contenir des caractères que parmi \"a-zA-Z0-9\", \"-\", \"_\" ou \"/\". Il ne doit pas être numérique ou commencer par un nombre suivi par \"-\"";
$lang['Permalink %s is already used by album %s'] = "Le lien permanent %s est déja utilisé par la catégorie %s";
$lang['Permalink history'] = "Historique des liens permanents";
$lang['Permalinks'] = "Liens permanents";
$lang['Permission denied'] = "Accès interdit";
$lang['Permission granted thanks to a group'] = "Accès autorisé grâce à l'appartenance aux groupes";
$lang['Permission granted'] = "Accès autorisé";
$lang['Photo informations updated'] = "Informations de l'image mises à jour";
$lang['Plugins'] = "Plugins";
$lang['Position'] = "Position";
$lang['Preferences'] = "Préférences";
$lang['Properties'] = "Propriétés";
$lang['Random photo'] = "Image au hasard";
$lang['Rate date'] = "Date de notation";
$lang['Rating by guests'] = "Notation par les invités";
$lang['Rating'] = "Notation";
$lang['Reject'] = "Rejeter";
$lang['Representant'] = "Représentant";
$lang['Representation of albums'] = "Représentation des catégories";
$lang['Representative'] = "Représentant";
$lang['Represents'] = "Représente";
$lang['Save order'] = "Sauvegarder l'ordre";
$lang['Save to permalink history'] = "Sauvegarder dans l'historique des liens permanents";
$lang['Select at least one album'] = "Sélectionner au moins une catégorie";
$lang['Select at least one photo'] = "Sélectionner au moins une image";
$lang['Select at least one user'] = "Sélectionner au moins un utilisateur";
$lang['Show info'] = "Montrer les informations";
$lang['Site manager'] = "Gestionnaire des sites";
$lang['Status'] = "Statut";
$lang['Statistics'] = "Statistiques";
$lang['Storage album'] = "Catégorie de stockage";
$lang['Sum of rates'] = "Somme des notes";
$lang['Tag "%s" already exists'] = "Le mot clé \"%s\" existe déjà";
$lang['Tag "%s" was added'] = "Le mot clé \"%s\" a été ajouté";
$lang['Tag selection'] = "Sélection de mots clés";
$lang['The %d following tags were deleted'] = "Les %d mots clés suivants ont été supprimés";
$lang['Unable to check for upgrade.'] = "Impossible de connaître la dernière version.";
$lang['Uninstall'] = "Désinstaller";
$lang['Use the default photo sort order (defined in the configuration file)'] = "Utiliser l'ordre de tri des images par défaut (défini dans le fichier de configuration)";
$lang['User comments validation'] = "Validation des commentaires d'utilisateurs";
$lang['Users'] = "Utilisateurs";
$lang['Validate'] = "Valider";
$lang['Validation'] = "Validation";
$lang['Version'] = "Version";
$lang['Virtual albums to move'] = "Catégories virtuelles à déplacer";
$lang['Virtual album name'] = "Nom de la catégorie virtuelle";
$lang['Webmaster cannot be deleted'] = "Le webmestre ne peut pas être supprimé";
$lang['You are running on development sources, no check possible.'] = "Vous travaillez avec les sources de développement, impossible de vérifier la dernière version.";
$lang['You cannot delete your account'] = "Vous ne pouvez pas supprimer votre compte";
$lang['You cannot move an album in its own sub album'] = "Vous ne pouvez pas déplacer une catégorie dans sa propre sous-catégorie";
$lang['You need to confirm deletion'] = "Vous devez confirmer la suppression";
$lang['add tags'] = "Ajouter les tags";
$lang['Associate to album'] = "Associer à la catégorie";
$lang['associate to group'] = "Associer au groupe";
$lang['Authorized'] = "Autorisés";
$lang['Add a virtual album'] = "Ajouter une catégorie virtuelle";
$lang['Authorize users to add comments on selected albums'] = "Autoriser les utilisateurs à ajouter des commentaires dans les catégories sélectionnées";
$lang['The name of an album must not be empty'] = "Le nom de la catégorie ne doit pas être vide";
$lang['Lock albums'] = "Verrouiller les catégories";
$lang['Private'] = "Catégorie privée";
$lang['Public'] = "Catégorie publique";
$lang['Find a new representant by random'] = "Trouver un nouveau représentant au hasard";
$lang['Public / Private'] = "Publique / Privée";
$lang['Manage authorizations for selected albums'] = "Gérer le type d'accès pour les catégories sélectionnées";
$lang['Virtual album added'] = "Catégorie virtuelle ajoutée";
$lang['Virtual album deleted'] = "Catégorie virtuelle supprimée";
$lang['Access type'] = "Type d'accès";
$lang['Comments'] = "Commentaires";
$lang['Information data registered in database'] = "Informations enregistrées dans la base de données";
$lang['Default display'] = "Affichage par défaut";
$lang['The gallery URL is not valid.'] = "L'adresse de la galerie n'est pas valide.";
$lang['Main'] = "Principale";
$lang['The number of comments a page must be between 5 and 50 included.'] = "Le nombre de commentaires d'utilisateurs par page doit être compris entre 5 et 50.";
$lang['Configuration'] = "Configuration";
$lang['confirm'] = "Confirmer";
$lang['Date'] = "Date";
$lang['delete album'] = "supprimer la catégorie";
$lang['Dissociate from album'] = "Dissocier de la catégorie";
$lang['dissociate from group'] = "Dissocier du groupe";
$lang['edit album permissions'] = "Modifier les permissions de la catégorie";
$lang['Album updated successfully'] = "Les informations de la catégorie ont été mises à jour avec succès.";
$lang['photos per page'] = "Nombre d'éléments par page à afficher";
$lang['High definition enabled'] = "Haute définition actif";
$lang['File'] = "Fichier";
$lang['Filesize'] = "Poids";
$lang['first photo added on %s'] = "premier élément ajouté le %s";
$lang['Forbidden'] = "Interdits";
$lang['global mode'] = "Mode global";
$lang['group "%s" added'] = "groupe \"%s\" ajouté";
$lang['group "%s" deleted'] = "groupe \"%s\" supprimé";
$lang['group "%s" updated'] = "groupe \"%s\" mis à jour";
$lang['group'] = "groupe";
$lang['The name of a group must not contain " or \' or be empty.'] = "Le nom du groupe ne doit pas contenir \" ou ' et ne doit pas être vide.";
$lang['This name is already used by another group.'] = "Ce nom est déjà utilisé par un autre groupe.";
$lang['Groups'] = "Groupes";
$lang['High definition'] = "Haute définition";
$lang['jump to album'] = "Se rendre dans la catégorie";
$lang['jump to photo'] = "Se rendre à l'image";
$lang['leave'] = "laisser";
$lang['Lock'] = "Verrouiller";
$lang['Locked'] = "Verrouillées";
$lang['manage album photos'] = "Gérer les éléments de la catégorie";
$lang['manage sub-albums'] = "Gérer les sous-catégories";
$lang['Manage'] = "Gérer";
$lang['maximum height'] = "Hauteur maximum";
$lang['maximum width'] = "Largeur maximum";
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = "Le temps d'exécution étant dépassé, le traitement doit continuer [Temps estimé: %d second].";
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = "Le temps d'exécution étant dépassé, le traitement doit continuer [Temps estimé: %d secondes].";
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = "Le temps de préparation de la liste des utilisateurs pour l'envoi est limité. Les autres utilisateurs ne sont pas listés.";
$lang['Time to send mail is limited. Others mails are skipped.'] = "Le temps d'envoi des courriels est limité. Les autres envois de courriel ont été ignorés.";
$lang['To send ?'] = "À envoyer ?";
$lang['Last send'] = "Dernier envoi";
$lang['email'] = "Courriel";
$lang['User'] = "Utilisateur";
$lang['Complementary mail content'] = "Contenu complémentaire au courriel	";
$lang['See you soon,'] = "À bientôt,";
$lang['Go to'] = "Rendez-vous sur";
$lang['Hello'] = "Bonjour";
$lang['New photos were added'] = "De nouveaux éléments ont été ajoutés";
$lang['on'] = "le";
$lang['between'] = "entre le";
$lang['and'] = "et le";
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = "Vous venez d'être inscrit par le webmestre du site pour recevoir des notifications par courriel.";
$lang['You have subscribed to receiving notifications by mail.'] = "Vous venez de vous inscrire pour recevoir des notifications par courriel.";
$lang['To subscribe'] = "Pour vous inscrire";
$lang['If you encounter problems or have any question, please send a message to'] = "En cas de problèmes ou de questions, envoyer un courriel à";
$lang['[NBM] Problems or questions'] = "[NBM] Problèmes ou questions";
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = "Vous venez d'être désinscrit par le webmestre du site pour ne plus recevoir la notification par courriel.";
$lang['You have unsubscribed from receiving notifications by mail.'] = "Vous venez de vous désinscrire pour ne plus recevoir la notification par courriel.";
$lang[', click on'] = ", cliquez sur";
$lang['To unsubscribe'] = "Pour vous désinscrire";
$lang['With blank value, gallery title will be used'] = "Si non renseigné, le titre de la galerie sera utilisé";
$lang['Notification'] = "Notification";
$lang['Error when sending email to %s [%s].'] = "Erreur lors de l'envoi du courriel à %s [%s].";
$lang['Mail sent to %s [%s].'] = "Courriel envoyé à %s [%s].";
$lang['%d mail was sent.'] = "%s courriel a été envoyé.";
$lang['%d mails were sent.'] = "%s courriels ont été envoyés.";
$lang['%d mail was not sent.'] = "%s courriel n'a pas été envoyé.";
$lang['%d mails were not sent.'] = "%s courriels n'ont pas été envoyés.";
$lang['No mail to send.'] = "Pas de courriel à envoyer.";
$lang['There is no available subscribers to mail.'] = "Il n'y a pas d'utilisateur à notifier par courriel.";
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = "Un utilisateur peut être notifié seulement si de nouveaux éléments sont disponibles pour cet utilisateur.";
$lang['Anyway only webmasters can see this tab and never administrators.'] = "Seul le webmaster a accès à cet onglet, pas les administrateurs.";
$lang['No user to send notifications by mail.'] = "Pas d'utilisateur pour envoyer des notifications par courriels.";
$lang['New photos added'] = "Nouveaux éléments ajoutés";
$lang['Subscribe to notification by mail'] = "Inscription à la notification par courriel";
$lang['Unsubscribe from notification by mail'] = "Désinscription à la notification par courriel";
$lang['Parameter'] = "Paramétrage";
$lang['Operation in progress'] = "Traitement en cours.";
$lang['Continue processing treatment'] = "Continuer le traitement en cours";
$lang['Complementary mail content'] = "Contenu complémentaire du courriel";
$lang['Add detailed content'] = "Ajout d'un contenu détaillé";
$lang['Send mail as'] = "Envoyer le courriel en tant que";
$lang['Send mail to users'] = "Envoie de courriel aux utilisateurs";
$lang['Send'] = "Envoie";
$lang['Options'] = "Options";
$lang['Send'] = "Envoyer";
$lang['Subscribed'] = "Inscrits";
$lang['Subscribe'] = "S'inscrire";
$lang['Parameters'] = "Paramètres";
$lang['Select recipients'] = "Sélection des destinataires";
$lang['Subscribe/unsubscribe users'] = "Inscrire/désinscrire les utilisateurs";
$lang['Unsubscribed'] = "Non inscrits";
$lang['%d parameter was updated.'] = "%d paramètre a été mis à jour.";
$lang['%d parameters were updated.'] = "%d paramètres ont été mis à jour.";
$lang['%d user was not updated.'] = "%d utilisateur n'a pas été mis à jour.";
$lang['%d users were not updated.'] = "%d utilisateurs n'ont pas été mis à jour.";
$lang['User %s [%s] was removed from the subscription list.'] = "L'utilisateur %s [%s] a été supprimé de la liste des inscrits.";
$lang['User %s [%s] was added to the subscription list.'] = "L'utilisateur %s [%s] a été ajouté à la liste des inscrits.";
$lang['%d user was updated.'] = "%d utilisateur a été mis à jour.";
$lang['%d users were updated.'] = "%d utilisateurs ont été mis à jour.";
$lang['User %s [%s] was not removed from the subscription list.'] = "L'utilisateur %s [%s] n'a pas été supprimé de la liste des inscrits.";
$lang['User %s [%s] was not added to the subscription list.'] = "L'utilisateur %s [%s] n'a pas été ajouté à la liste des inscrits.";
$lang['User %s [%s] added.'] = "Utilisateur %s [%s] ajouté.";
$lang['Warning: subscribing or unsubscribing will send mails to users'] = "Attention, l'inscription ou la désincription génère l'envoi de courriel aux utilisateurs concernés";
$lang['Send mail on HTML format'] = "Envoyer le courriel au format HTML";
$lang['Include display of recent photos grouped by dates'] = "Inclure l'affichage des dernières images groupées par dates";
$lang['Available only with HTML format'] = "Disponible uniquement avec le format HTML";
$lang['no write access'] = "Pas d'accès en écriture";
$lang['Permissions'] = "Permissions";
$lang['private'] = "privé";
$lang['Properties'] = "Propriétés";
$lang['public'] = "public";
$lang['Purge never used notification feeds'] = "Purger les flux de notification jamais utilisés";
$lang['Purge sessions'] = "Purger les sessions";
$lang['randomly represented'] = "représentant au hasard";
$lang['registration date'] = "date d'enregistrement";
$lang['clean'] = "nettoyer";
$lang['remove remote listing.xml file'] = "supprimer le fichier listing.xml distant";
$lang['generate listing'] = "générer le listing";
$lang['generate file listing.xml on remote site'] = "générer le fichier listing.xml sur le site distant";
$lang['Create this site'] = "Créer ce site";
$lang['A local listing.xml file has been found for'] = "Un fichier listing.xml local a été trouvé pour";
$lang['read local listing.xml and update'] = "lire le listing.xml local et mettre à jour";
$lang['test'] = "tester";
$lang['test this remote site'] = "tester ce site distant";
$lang['remove tags'] = "supprimer les tags";
$lang['Repair and optimize database'] = "Réparer et optimiser la base de données";
$lang['selection'] = "sélection";
$lang['set to'] = "changer en";
$lang['singly represented'] = "représentant fixe";
$lang['This site already exists'] = "Ce site existe déjà";
$lang['Create a new site : (give its URL to create_listing_file.php)'] = "Créer un nouveau site distant : (donner son URL vers create_listing_file.php)";
$lang['created'] = "créé";
$lang['Delete'] = "supprimer";
$lang['delete this site and all its attached elements'] = "supprimer ce site et toutes les informations associées";
$lang['an error happened'] = "une erreur est survenue";
$lang['file create_listing_file.php on remote site was not found'] = "le fichier create_listing_file.php est introuvable sur le site distant";
$lang['Local'] = "Local";
$lang['Remote'] = "Distant";
$lang['synchronize'] = "synchroniser";
$lang['update the database from files'] = "met à jour la base de données à partir des fichiers";
$lang['status'] = "Statut";
$lang['Directory'] = "Répertoire";
$lang['sub-albums'] = "sous-catégories";
$lang['synchronize metadata'] = "Synchroniser les méta-données";
$lang['synchronize'] = "synchroniser";
$lang['target'] = "Cible";
$lang['Thumbnail'] = "Miniature";
$lang['title'] = "Titre";
$lang['Album list management'] = "Gestion des catégories";
$lang['Piwigo configuration'] = "Configuration de Piwigo";
$lang['Edit album'] = "Modifier une catégorie";
$lang['Group management'] = "Gestion des groupes";
$lang['User list'] = "Liste des utilisateurs";
$lang['Edit photo information'] = "Modifier les informations d'une image";
$lang['Thumbnail creation'] = "Création des miniatures";
$lang['Database synchronization with files'] = "Synchronisation de la base à partir des fichiers de";
$lang['all'] = "Tout";
$lang['photos without thumbnail (jpeg and png only)'] = "images sans miniature (jpeg et png uniquement)";
$lang['height must be a number superior to'] = "la hauteur doit un entier supérieur à";
$lang['width must be a number superior to'] = "la largeur doit être un entier supérieur à";
$lang['for the file format'] = "pour le format de fichier";
$lang['No missing thumbnail'] = "Aucune miniature ne manque";
$lang['Photo unreachable or no support'] = "Image inaccessible ou format non supporté";
$lang['GD version'] = "version de GD";
$lang['Miniaturization parameters'] = "Paramètre de miniaturisation";
$lang['generated in'] = "générée en";
$lang['Results of miniaturization'] = "Résultats de la miniaturisation";
$lang['General statistics'] = "Statistiques générales";
$lang['max time'] = "temps maximal";
$lang['average time'] = "temps moyen";
$lang['min time'] = "temps minimal";
$lang['number of miniaturized photos'] = "nombre de miniatures créées";
$lang['total time'] = "temps total";
$lang['for this file format'] = "pour ce format de fichier";
$lang['unit mode'] = "Mode unitaire";
$lang['Unlocked'] = "Déverrouillées";
$lang['unset'] = "vider";
$lang['Update albums informations'] = "Mettre à jour les informations des catégories";
$lang['Update photos information'] = "Mettre à jour les informations des images";
$lang['Synchronize'] = "Synchroniser";
$lang['reduce to single existing albums'] = "Traiter uniquement une catégorie";
$lang['Choose an option'] = "Choisir une option";
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = "Afficher un maximum d'informations (catégories ajoutées, éléments ajoutés, catégories et éléments supprimés)";
$lang['Piwigo version differs on the remote site'] = "La version Piwigo sur le site distant est différente";
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = "Les version de create_listing_file.php sur le site distant et Piwigo doivent être les mêmes";
$lang['listing.xml file was not found'] = "le fichier listing.xml est introuvable";
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = "le fichier listing.xml est introuvable sur le site distant. Ce fichier est généré avec la commande \"générer le listing\" dans le gestionnaire de sites";
$lang['Error list'] = "Liste des erreurs";
$lang['Errors caption'] = "Légende des erreurs";
$lang['Detailed informations'] = "Informations détaillées";
$lang['File/directory read error'] = "Erreur d'ouverture fichier/répertoire";
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = "Le fichier ou répertoire ne peut pas être accessible (soit il n'existe pas, soit l'accès est refusé)";
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = "Chaque fichier image requiert une miniature. La miniature doit être présente dans le sous-répertoire \"thumbnail\" du répertoire de la catégorie. Le nom du fichier de la miniature doit commencer avec le paramètre de configuration \"prefix_thumbnail\" et l'extension du nom du fichier doit être parmi la liste suivante :";
$lang['missing thumbnail'] = "miniature manquante";
$lang['albums deleted in the database'] = "catégories supprimées de la base de données";
$lang['photos deleted from the database'] = "éléments supprimés de la base de données";
$lang['photos candidates for metadata synchronization'] = "images candidates à la synchronisation avec les méta-données";
$lang['photos informations synchronized with files metadata'] = "informations des images synchronisées avec les méta-données";
$lang['errors during synchronization'] = "erreurs survenues durant la synchronisation";
$lang['albums added in the database'] = "catégories ajoutées dans la base de données";
$lang['photos added in the database'] = "éléments ajoutés dans la base de données";
$lang['photos updated in the database'] = "éléments mis à jour dans la base de données";
$lang['Search for new images in the directories'] = "Chercher les nouvelles images dans les répertoires";
$lang['added'] = "ajouté";
$lang['deleted'] = "supprimé";
$lang['Metadata synchronization results'] = "Résultat de la synchronisation des méta-données";
$lang['only perform a simulation (no change in database will be made)'] = "Simuler uniquement (aucun changement ne sera fait dans la base de données)";
$lang['[Simulation]'] = "[Simulation]";
$lang['Simulation'] = "Simulation";
$lang['directories + files'] = "Répertoires + fichiers";
$lang['only directories'] = "Répertoires uniquement";
$lang['synchronize files structure with database'] = "Synchroniser la structure des fichiers avec la base de données";
$lang['synchronize files metadata with database photos informations'] = "Synchroniser les informations des éléments de la base de données à partir des méta-données des fichiers";
$lang['even already synchronized photos'] = "Même les éléments déjà synchronisés";
$lang['Used metadata'] = "Méta-données employées";
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = "Le nom des répertoires et des fichiers ne doit être constitué que de lettres, de chiffres, de \"-\", \"_\" et \".\"";
$lang['wrong filename'] = "nom de fichier erroné";
$lang['Upload'] = "Ajout";
$lang['user "%s" added'] = "utilisateur \"%s\" ajouté";
$lang['User status'] = "Statut de l'utilisateur";
$lang['user_status_admin'] = "Administrateur";
$lang['user_status_generic'] = "Générique";
$lang['user_status_guest'] = "Invité";
$lang['user_status_normal'] = "Visiteur";
$lang['user_status_webmaster'] = "Webmestre";
$lang['Users'] = "Utilisateurs";
$lang['Virtual album'] = "Catégorie virtuelle";
$lang['Waiting'] = "En attente";
$lang['default'] = "par défaut";
$lang['Toggle \'default group\' property'] = "Inverser la propriété 'groupe par défaut'";
$lang['Advanced features'] = "Fonctions avancées";
$lang['Specials'] = "Spéciales";
$lang['Overall'] = "Vue globale";
$lang['Year'] = "Année";
$lang['Month'] = "Mois";
$lang['Day'] = "Jour";
$lang['Pages seen'] = "Pages vues";
$lang['Time'] = "Heure";
$lang['User'] = "Utilisateur";
$lang['IP'] = "IP";
$lang['Element'] = "Élément";
$lang['Section'] = "Section";
$lang['Tags'] = "Mots clés";
$lang['Save page visits by guests'] = "Enregistrer les pages visitées par les invités";
$lang['Save page visits by users'] = "Enregistrer les pages visitées par les utilisateurs";
$lang['Save page visits by administrators'] = "Enregistrer les pages visitées par les administrateurs";
$lang['Properties'] = "Propriétés";
$lang['An information email was sent to group "%s"'] = "Un courriel d'informations a été envoyé aux membres du groupe \"%s\"";
$lang['Send an information email to group members'] = "Envoyer un courriel d'informations aux membres d'un groupe";
$lang['Group'] = "Groupe";
$lang['[%s] Visit album %s'] = "[%s] Venez visiter la catégorie %s";
$lang['Hello,'] = "Bonjour,";
$lang['See you soon.'] = "À bientôt.";
$lang['Discover album:'] = "Venez découvrir la catégorie:";
$lang['Mail content'] = "Contenu du courriel";
$lang['none'] = "aucun";
$lang['high'] = "élevé";
$lang['other'] = "autre";
$lang['Element type'] = "Type d'élément";
$lang['User'] = "Utilisateur";
$lang['Image id'] = "Identifiant image";
$lang['Summary'] = "Résumé";
$lang['%d line filtered'] = "%d ligne filtrée";
$lang['%d lines filtered'] = "%d lignes filtrées";
$lang['%d guest'] = "%d invité";
$lang['%d guests'] = "%d invités";
$lang['Hour'] = "Heure";
$lang['guest'] = "invité";
$lang['default values'] = "valeurs par défaut";
$lang['High filesize'] = "Taille du fichier haute résolution";
$lang['Guest cannot be deleted'] = "L'invité ne peut pas être supprimé";
$lang['Default user cannot be deleted'] = "L'utilisateur par défaut ne peut pas être supprimé";
$lang['Purge history detail'] = "Purger le détail de l'historique";
$lang['Purge history summary'] = "Purger le récapitulatif de l'historique";
$lang['Check integrity'] = "Contrôle d'intégrité";
$lang['Anomaly'] = "Anomalie";
$lang['Correction'] = "Correction";
$lang['Automatic correction'] = "Correction automatique";
$lang['Impossible automatic correction'] = "Correction automatique impossible";
$lang['Correction applied with success'] = "Correction appliquée avec succès";
$lang['Correction applied with error'] = "Correction appliquée avec erreur";
$lang['%d anomaly has been detected.'] = "%d anomalie a été détectée.";
$lang['%d anomalies have been detected.'] = "%d anomalies ont été détectées.";
$lang['%d anomaly has been corrected.'] = "%d anomalie a été corrigée.";
$lang['%d anomalies have been detected corrected.'] = "%d anomalies ont été détectées et corrigées.";
$lang['%d anomaly has not been corrected.'] = "%d anomalie n'a pu être corrigée.";
$lang['%d anomalies have not been corrected.'] = "%d anomalies n'ont pu être corrigées.";
$lang['Go to %s or %s for more informations'] = "Allez sur %s ou %s pour plus d'informations";
$lang['the forum'] = "le forum";
$lang['the wiki'] = "le wiki";
$lang['%s value is not correct file because exif are not supported'] = "La valeur de %s est incorrecte parce que les exif ne sont pas supportés";
$lang['%s must be to set to false in your local/config/config.inc.php file'] = "%s doit être mis à \"false\" dans votre fichier local/config/config.inc.php";
$lang['Main "guest" user does not exist'] = "L'utilisateur \"invité\" principal n'existe plus";
$lang['Main "guest" user status is incorrect'] = "Le statut de l'utilisateur \"invité\" principal est incorrect";
$lang['Default user does not exist'] = "L'utilisateur par défaut n'existe pas";
$lang['Main "webmaster" user does not exist'] = "L'utilisateur \"Webmestre\" principal n'existe pas";
$lang['Main "webmaster" user status is incorrect'] = "Le statut de l'utilisateur \"Webmestre\" principal est incorrect";
$lang['User "%s" created with "%s" like password'] = "Utilisateur \"%s\" créé avec le mot de passe \"%s\"";
$lang['Status of user "%s" updated'] = "Statut de l'utilisateur \"%s\" mis à jour";
$lang['add new photos to caddie'] = "Ajouter les nouveaux éléments au panier";
$lang['No display'] = "Pas d'affichage";
$lang['Classic display'] = "Affichage classique";
$lang['Hoverbox display'] = "Affichage lors du survol";
$lang['Mail address is obligatory for all users'] = "L'adresse courriel est obligatoire pour tous les utilisateurs";
$lang['Minimum privacy level'] = "Niveau minimal de confidentialité";
$lang['Privacy level'] = "Niveau de confidentialité";
$lang['Level 0'] = "---";
$lang['Level 1'] = "Contacts";
$lang['Level 2'] = "Amis";
$lang['Level 4'] = "Famille";
$lang['Level 8'] = "Admins";
$lang['Reinitialize check integrity'] = "Réinitialiser les contrôles d'intégrité";
$lang['Check all'] = "Tout cocher";
$lang['Uncheck all'] = "Tout décocher";
$lang['Check automatic corrections'] = "Cocher les corrections automatiques";
$lang['Apply selected corrections'] = "Appliquer les corrections sélectionnées";
$lang['Ignore selected anomalies'] = "Ignorer les anomalies sélectionnées";
$lang['Refresh'] = "Rafraîchir";
$lang['The anomaly will be ignored until next application version'] = "L'anomalie sera ignorée jusqu'à la prochaine version de l'application";
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = "L'anomalie ne sera plus ignorée du fait de sa correction";
$lang['%d anomaly has been ignored.'] = "%d anomalie a été ignorée.";
$lang['%d anomalies have been ignored.'] = "%d anomalies ont été ignorées.";
$lang['Plugins which need upgrade'] = "Plugins à mettre à jour";
$lang['Plugin list'] = "Liste des plugins";
$lang['Check for updates'] = "Rechercher les mises à jour";
$lang['Other plugins'] = "Autres plugins disponibles";
$lang['Last revisions'] = "Dernières révisions";
$lang['Delete'] = "Supprimer";
$lang['Are you sure you want to delete this plugin?'] = "Êtes-vous sûr de vouloir supprimer ce plugin?";
$lang['Are you sure you want to install this plugin?'] = "Êtes-vous sûr de vouloir installer ce plugin?";
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = "Êtes-vous sur de vouloir installer cette mise à jour? Vous devez vérifiez que cette mise à jour ne nécessite pas de désinstallation préalable.";
$lang['%s has been successfully upgraded.'] = "%s a été mis à jour avec succès.";
$lang['Plugin has been successfully copied'] = "Le plugin a été copié avec succès.";
$lang['You might go to plugin list to install and activate it.'] = "Rendez-vous dans la liste des plugins pour l'installer et l'activer.";
$lang['Can\'t create temporary file.'] = "Impossible de créer un fichier temporaire.";
$lang['Can\'t download archive.'] = "Impossible de télécharger l'archive.";
$lang['Can\'t read or extract archive.'] = "Impossible de lire ou d'extraire l'archive.";
$lang['An error occured during extraction (%s).'] = "Une erreur est survenue pendant l'extraction des fichiers (%s).";
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = "Vérifiez les permissions du dossier \"plugins\" et de ses sous-dossiers (CHMOD).";
$lang['Can\'t connect to server.'] = "Impossible de se connecter au serveur.";
$lang['Purge compiled templates'] = "Purger les templates compilés";
$lang['Upload'] = "Ajout";
$lang['ACCESS_0'] = "Accès libre";
$lang['ACCESS_1'] = "Accès à tous";
$lang['ACCESS_2'] = "Accès aux utilisateurs inscrits";
$lang['ACCESS_3'] = "Accès aux administrateurs";
$lang['ACCESS_4'] = "Accès aux webmestres";
$lang['ACCESS_5'] = "Pas d'accès";
$lang['Support'] = "Support";
$lang['Documentation'] = "Documentation";
$lang['A new version of Piwigo is available.'] = "Une nouvelle version de Piwigo est disponible.";
$lang['Piwigo Administration'] = "Administration de Piwigo";
$lang['Piwigo version'] = "Version de Piwigo";
$lang['You are running the latest version of Piwigo.'] = "Vous utilisez la dernière version de Piwigo.";
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = "La version de %s [%s] installée est incompatible avec la version requise [%s]";
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = "Vous devez mettre à jour votre système pour profiter pleinement de l'application, sinon l'application ne fonctionnera pas correctement, voire pas du tout";
$lang['Deleted on'] = "Supprimés sur";
$lang['Last hit'] = "dernier score";
$lang['GD library is missing'] = "la bibliothèque GD est manquante";
$lang['Templates'] = "Templates (modèles)";
$lang['Extend for templates'] = "Étendre les templates";
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = "Remplacement des templates d'origine par vos templates personnalisés issus du dossier template-extension";
$lang['Replacers (customized templates)'] = "Remplaçants (templates modifiés)";
$lang['Original templates'] = "Templates d'origine";
$lang['Optional URL keyword'] = "Paramètre facultatif de l'URL";
$lang['Templates configuration has been recorded.'] = "La configuration des templates a été enregistrée.";
$lang['All optimizations have been successfully completed.'] = "Toutes les optimisations ont été réalisées avec succès.";
$lang['Optimizations have been completed with some errors.'] = "Les optimisations réalisées comportent certaines erreurs.";
$lang['Modify information'] = "Modifier les informations";
$lang['edit album'] = "éditer les informations de cette catégorie";
$lang['nothing'] = "Rien";
$lang['overrides existing values with empty ones'] = "Écraser les données existantes avec des données vides";
$lang['manage photo ranks'] = "gérer l'ordre des images";
$lang['Manage photo ranks'] = "Gérer l'ordre des images";
$lang['Edit ranks'] = "Modifier l'ordre";
$lang['No photo in this album'] = "Aucun élément dans cette catégorie";
$lang['Images manual order was saved'] = "L'ordre manuel des images a été sauvegardé";
$lang['ranks'] = "rangs";
$lang['By rank'] = "Par le rang";
$lang['Manual order'] = 'Ordre manuel';
$lang['Drag to re-order'] = "Cliquer-glisser pour ré-organiser";
$lang['Quick Local Synchronization'] = "Synchronisation rapide";
$lang['No photo can be deleted'] = "Aucune photo ne peut être supprimée";
$lang['Delete selected photos'] = "Supprimer les photos sélectionnées";
$lang['%d photo was deleted'] = "%d photo a été supprimée";
$lang['%d photos were deleted'] = "%d photos ont été supprimées";
$lang['Downloads'] = "Téléchargements";
$lang['Released on'] = "Publié le";
$lang['Number of downloads'] = "Nombre de téléchargements";
$lang['Piwigo Announcements Newsletter'] = "Newsletter Piwigo";
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = "Gardez le contact avec le projet Piwigo, abonnez-vous à la newsletter. Vous recevrez un ecourriel lorsqu'une nouvelle version est disponible (parfois un bug de sécurité est corrigé, il est important de le savoir et de mettre à jour) ou qu'un événement majeur survient sur le projet. Quelques messages par an seulement.";
$lang['Subscribe %s'] = "Abonner %s";
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = "Abonner %s à la newsletter Piwigo";
$lang['Purge search history'] = "Purger l'historique des recherches";
$lang['Hide'] = "Masquer";
$lang['Password is missing. Please enter the password.'] = "Le mot de passe manque. Veuillez saisir le mot de passe.";
$lang['Password confirmation is missing. Please confirm the chosen password.'] = "La confirmation du mot de passe manque. Veuillez confirmer le mot de passe choisi.";
$lang['Password confirmation error.'] = "Erreur de confirmation du mot de passe.";
$lang['Allow users to edit their own comments'] = "Autoriser les utilisateurs à modifier leurs propres commentaires";
$lang['Allow users to delete their own comments'] = "Autoriser les utilisateurs à supprimer leurs propres commentaires";
$lang['Email administrators when a comment is modified'] = "Notifier les administrateurs quand un commentaire est modifié";
$lang['Email administrators when a comment is deleted'] = "Notifier les administrateurs quand un commentaire est supprimé";
$lang['Cannot delete the old permalink !'] = "Impossible de supprimer cet ancien lien permanent !";
$lang['Hit'] = "Pointage";
$lang['Tools'] = "Outils";
$lang['Photos'] = "Photos";
$lang['Themes'] = "Thèmes";
$lang['Instructions to use Piwigo'] = "Instructions pour utiliser Piwigo";
$lang['Installed Themes'] = "Thèmes installés";
$lang['Add New Theme'] = "Ajouter un thème";
$lang['Forbid this theme to users'] = "Interdire ce thème aux utilisateurs";
$lang['Set as default theme for unregistered and new users'] = "Thème par défaut pour les invités et les nouveaux utilisateurs";
$lang['unknown'] = 'inconnu';
$lang['Upload Photos'] = 'Ajoutez des photos';
$lang['Drop into album'] = 'Mettre dans une catégorie';
$lang['+ Add an upload box'] = '+ Ajouter une autre boîte de transfert';
$lang['Upload'] = 'Transférer';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Créez le répertoire "%s" à la racine de votre installation Piwigo';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Donnez les droits en écriture (chmod 777) sur le répertoire "%s" à la racine de votre installation Piwigo';
$lang['existing album'] = 'catégorie existante';
$lang['create a new album'] = 'créer une nouvelle catégorie';
$lang['Album name'] = 'Nom de la catégorie';
$lang['Album "%s" has been added'] = 'La catégorie "%s" a été ajoutée';
$lang['Uploaded Photos'] = 'Photos ajoutées ';
$lang['%d photos uploaded'] = '%d photos ajoutées';
$lang['Privacy level set to "%s"'] = 'Niveau de confidentialité "%s"';
$lang['Album "%s" now contains %d photos'] = 'La catégorie "%s" contient désormais %d photos';
$lang['Manage this set of %d photos'] = 'Gérer ce lot de %d photos';
$lang['Select files'] = 'Choisir des fichiers';
$lang['Everybody'] = 'Tout le monde';
$lang['Who can see these photos?'] = 'Qui peut voir ces photos ?';
$lang['Who can see this photo?'] = 'Qui peut voir cette photo ?';
$lang['The websize maximum width must be a number between %d and %d'] = 'La largeur maximum pour la photo taille web doit être un chiffre compris entre %d et %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'La hauteur maximum pour la photo taille web doit être un chiffre compris entre %d et %d';
$lang['The websize image quality must be a number between %d and %d'] = 'La qualité d\'image pour la photo taille web doit être un chiffre compris entre %d et %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'La largeur maximum pour la miniature doit être un chiffre compris entre %d et %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'La hauteur maximum pour la miniature doit être un chiffre compris entre %d et %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'La qualité d\'image pour la miniature doit être un chiffre compris entre %d et %d';
$lang['Settings'] = 'Configuration';
$lang['Web size photo'] = 'Photo taille web';
$lang['Resize'] = 'Redimensionner';
$lang['Maximum Width'] = 'Largeur maximum';
$lang['pixels'] = 'pixels';
$lang['Maximum Height'] = 'Hauteur maximum';
$lang['Image Quality'] = 'Qualité d\'image';
$lang['Thumbnail'] = 'Miniature';
$lang['Save Settings'] = 'Enregistrer les paramètres';
$lang['Your configuration settings are saved'] = 'Vos paramètres de configurations sont enregistrés';
$lang['Active Themes'] = 'Thèmes activés';
$lang['Add write access to the "%s" directory'] = 'Ajoutez l\'accès en écriture pour le répertoire "%s"';
$lang['Administration Home'] = 'Accueil administration';
$lang['Change Admin Colors'] = 'Modifier les couleurs de l\'administration';
$lang['Delete this theme'] = 'Supprimer ce thème';
$lang['Directory does not exist'] = 'Le répertoire n\'existe pas';
$lang['Download,'] = 'Téléchargez,';
$lang['FTP + Synchronization'] = 'FTP + Synchronisation';
$lang['Get Support on Piwigo Forum'] = 'Obtenir de l\'aide sur le forum Piwigo';
$lang['Help Me'] = 'À l\'aide';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'L\'activation de ce thème est impossible, car le thème parent est manquant : %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Ce thème ne peut être supprimé, car d\'autres thème dépendent de lui : %s';
$lang['Inactive Themes'] = 'Thèmes désactivés';
$lang['Install on your computer,'] = 'Installez sur votre ordinateur,';
$lang['Make this theme available to users'] = 'Rendre ce thème disponible aux utilisateurs';
$lang['Page end'] = 'Fin de la page';
$lang['Piwigo Uploader'] = 'Piwigo Uploader';
$lang['Operation in progress'] = 'Traitement en cours.';
$lang['Please wait...'] = 'Veuillez patienter ...';
$lang['Read Piwigo Documentation'] = 'Lire la documentation Piwigo';
$lang['Start pLoader and add your photos.'] = 'Démarrez pLoader et ajoutez vos photos.';
$lang['Switch to clear or dark colors for administration'] = 'Choisir des couleurs claires ou sombres pour l\'administration';
$lang['Theme has been successfully installed'] = 'Le thème a été installé avec succès';
$lang['Visit Gallery'] = 'Visiter la galerie';
$lang['Visit Piwigo project website'] = 'Visiter le site web du projet Piwigo';
$lang['Guest Settings'] = 'Paramètres visiteur';
$lang['Main Page'] = 'Page principale';
$lang['Photo Page'] = 'Page de la photo';
$lang['Activate Navigation Bar'] = 'Activer la barre de navigation';
$lang['Activate Navigation Thumbnails'] = 'Activer les miniatures de navigation';
$lang['Activate icon "%s"'] = 'Activer l\'icône "%s"';
$lang['Activate field "%s"'] = 'Activer le champ "%s"';
$lang['Photo Properties'] = 'Propriétés de la photo';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader signifie <em>Piwigo Uploader</em>. Depuis votre ordinateur, pLoader prépare vos photos et les transfert vers votre galerie photo Piwigo.';
$lang['Languages'] = 'Langues';
$lang['Installed Languages'] = 'Langues installées';
$lang['Add New Language'] = 'Ajouter une langue';
$lang['Language has been successfully installed'] = 'La langue a été installée avec succès';
$lang['Allow user customization'] = "Permettre la personnalisation de l'affichage";
$lang['Select:'] = 'Sélectionner :';
$lang['None'] = 'Rien';
$lang['Invert'] = 'Inverser';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Impossible de désactiver ce thème, il doit rester au moins un thème activé.';
$lang['Webmaster status is required.'] = 'Vous devez avoir le status de "webmaster".';
$lang['Bound Theme'] = 'Thème rattaché';
$lang['Allow rating'] = "Permettre les notations";
$lang['Select at least one comment'] = 'Sélectionnez au moins un commentaire';
$lang['Active Plugins'] = 'Plugins activés';
$lang['Inactive Plugins'] = 'Plugins désactivés';
$lang['Missing Plugins'] = 'Plugins manquants';
$lang['Uninstalled Plugins'] = 'Plugins non installés';
$lang['By %s'] = 'Par %s';
$lang['Visit plugin site'] = 'Visitez le site du plugin';
$lang['Active Languages'] = 'Langues activées';
$lang['Delete this language'] = 'Supprimer cette langue';
$lang['Forbid this language to users'] = 'Interdire cette langue aux utilisateurs';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Impossible de désactiver cette langue, commencez par définir une autre langue par défaut.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Impossible de désactiver cette langue, il doit rester au moins une langue.';
$lang['Inactive Languages'] = 'Langues désactivées';
$lang['Make this language available to users'] = 'Rendre cette langue disponible aux utilisateurs';
$lang['Set as default language for unregistered and new users'] = 'Langue par défaut pour les invités et les nouveaux utilisateurs';
$lang['Add Photos'] = 'Ajouter des photos';
$lang['Download'] = 'Télécharger';
$lang['Miscellaneous'] = 'Divers';
$lang['The following tag was deleted'] = 'Le mot clé suivant a été supprimé';
$lang['Virtual Links'] = 'Liens virtuels';
$lang['There is no other language available.'] = 'Il n\'y a pas d\'autre langue disponible.';
$lang['There is no other plugin available.'] = 'Il n\'y a pas d\'autre plugin disponible.';
$lang['There is no other theme available.'] = 'Il n\'y a pas d\'autre thème disponible.';
$lang['delete'] = 'effacer';
$lang['Add another set of photos'] = 'Ajouter d\'autres photos';
$lang['Order of menubar items has been updated successfully.'] = 'L\'ordre des éléments du menu a été mis à jour avec succès.';
$lang['This theme was not designed to be directly activated'] = 'Ce thème n\'est pas conçu pour être activé directement';
$lang['Pending Comments'] = 'Commentaires en attente';
$lang['Menu Management'] = 'Menus';
$lang['%d of %d photos selected'] = '%d photos sur %d sont sélectionnées';
$lang['Action'] = 'Action';
$lang['Add a filter'] = 'Ajouter un filtre';
$lang['Album photos associated to the following albums: %s'] = 'Les photos de l\'album ont été associées aux albums suivants : %s';
$lang['Albums automatically sorted'] = 'Les albums ont été triés automatiquement';
$lang['All %d photos are selected'] = 'Toutes les %d photos du lot sont sélectionnées';
$lang['Apply action'] = 'Appliquer l\'action';
$lang['automatic order'] = 'ordre automatique';
$lang['Batch Manager'] = 'Gestion par lot';
$lang['Choose an action'] = 'Choisir une action';
$lang['Delete orphan tags'] = 'Supprimer les mots clés orphelins';
$lang['delete photo'] = 'supprimer la photo';
$lang['duplicates'] = 'doublons';
$lang['Error on file "%s" : %s'] = 'Erreur sur le fichier "%s" : %s';
$lang['Exif extension not available, admin should disable exif use'] = 'L\'extension Exif n\'est pas disponible, un administrateur devrait désactiver l\'utilisation des métadonnées Exif';
$lang['Failed to write file to disk'] = 'Échec à l\'écriture du fichier sur le serveur';
$lang['File upload stopped by extension'] = 'Le transfert du fichier a été arrêté par une extension';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'Dans votre fichier php.ini, la variable upload_max_filesize (%sB) est plus grande que post_max_size (%sB), vous devriez modifier ce paramètre';
$lang['include child albums'] = 'inclure les sous-albums';
$lang['Keep high definition'] = 'Conserver la haute définition';
$lang['last import'] = 'dernière importation';
$lang['manual order'] = 'ordre manuel';
$lang['Missing a temporary folder'] = 'Impossible de trouver le répertoire temporaire';
$lang['No file was uploaded'] = 'Aucun fichier n\'a été transféré';
$lang['No photo in the current set.'] = 'Aucune photo dans le lot.';
$lang['No photo selected, %d photos in current set'] = 'Aucune photo sélectionnée parmi les %d photos du lot';
$lang['No photo selected, no action possible.'] = 'Aucune photo sélectionnée, aucune action possible.';
$lang['on the %d selected photos'] = 'sur les %d photos sélectionnées';
$lang['Orphan tags deleted'] = 'Mots clés orphelins supprimés';
$lang['predefined filter'] = 'filtre prédéfini';
$lang['Refresh photo set'] = 'Rafraîchir le lot de photos';
$lang['Remove all filters'] = 'Supprimer tous les filtres';
$lang['remove author'] = 'supprimer l\'auteur';
$lang['remove creation date'] = 'supprimer la date de création';
$lang['Remove from caddie'] = 'Retirer du panier';
$lang['remove this filter'] = 'supprimer ce filtre';
$lang['remove title'] = 'supprimer le titre';
$lang['Selection'] = 'Sélection';
$lang['Set author'] = 'Définir l\'auteur';
$lang['Set creation date'] = 'Définir la date de création';
$lang['Set title'] = 'Définir le titre';
$lang['The high definition image quality must be a number between %d and %d'] = 'La qualité d\'image pour la haute définition doit être un chiffre compris entre %d et %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'La hauteur maximale pour la haute définition doit être un chiffre compris entre %d et %d';
$lang['The high definition maximum width must be a number between %d and %d'] = 'La largeur maximale pour la haute définition doit être un chiffre compris entre %d et %d';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Le poids du fichier transféré dépasse la valeur de MAX_FILE_SIZE définie dans le formulaire HTML';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Le poids du fichier transféré dépasse la valeur de upload_max_filesize définie dans votre fichier php.ini: %sB';
$lang['The uploaded file was only partially uploaded'] = 'Le fichier n\'a été que partiellement transféré';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Le poids total des fichiers transférés dépasse la valeur de post_max_size dans votre fichier php.ini: %sB';
$lang['The whole page'] = 'Toute la page';
$lang['The whole set'] = 'Tout le lot';
$lang['Type here the author name'] = 'Entrez ici le nom de l\'auteur';
$lang['Type here the title'] = 'Entrez ici le titre';
$lang['Unknown upload error'] = 'Erreur inconnue survenue lors du transfert';
$lang['Week starts on'] = 'La semaine commence le';
$lang['with no album'] = 'sans album';
$lang['with no tag'] = 'sans mot clef';
$lang['with no virtual album'] = 'sans album virtuel';
$lang['You have %d orphan tags: %s.'] = 'Vous avez %d mots clés orphelins: %s.';
$lang['Themes which need upgrade'] = 'Thèmes à mettre à jour';
$lang['Languages which need upgrade'] = 'Langues à mettre à jour';
$lang['All themes are up to date.'] = 'Tous les thèmes sont à jour.';
$lang['All plugins are up to date.'] = 'Tous les greffons sont à jour.';
$lang['All languages are up to date.'] = 'Toutes les langues sont à jour.';
$lang['Visit theme site'] = 'Visitez le site du thème';
$lang['Visit language site'] = 'Visitez le site de la langue';
$lang['New Version'] = 'Nouvelle version';
$lang['Obsolete Plugins'] = 'Greffons périmés';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'ATTENTION! Ce greffon n\'a pas l\'air d\'être compatible avec votre version de Piwigo.';
$lang['Do you want to activate anyway?'] = 'Voulez-vous l\'activer quand même?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'CE GREFFON FAIT DÉSORMAIS PARTIE DU CŒUR DE PIWIGO! SUPPRIMEZ-LE.';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERREUR: CE GREFFON EST MANQUANT MAIS TOUJOURS INSTALLÉ! DÉSINSTALLEZ-LE.';
$lang['display'] = 'Afficher';
$lang['Restore'] = "Restaurer";
$lang['Restore default configuration. You will lose your plugin settings!'] = "Restaurer la configuration par défaut? Vous perdrez vos réglages personnels !";
$lang['Show menubar'] = "Afficher le menu";
$lang['Learn more'] = 'En savoir plus';
$lang['Rate'] = 'Note';
$lang['Average rate'] = 'Note moyenne';
$lang['Activate icon "new" next to albums and pictures'] = 'Afficher l\'icône "nouveau" à côté des albums et des photos';
$lang['Add a criteria'] = 'Ajouter un critère';
$lang['Deactivate all'] = 'Désactiver tout';
$lang['Default photos order'] = 'Ordre par défaut des photos';
$lang['new'] = 'nouveau';
$lang['No results'] = 'Pas de résultat';
$lang['Searching...'] = 'Recherche...';
$lang['Type in a search term'] = 'Entrez un terme de recherche';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Vous ne pouvez définir l\'ordre par défaut des photos car vous avez un paramètre personnalisé dans votre configuration locale.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Vous avez spécifié <i>$conf[\'order_by\']</i> dans votre fichier de configuration, ce paramètre est obsolète, veuillez le supprimer ou le renommer en <i>$conf[\'order_by_custom\']</i> !';
$lang['Regenerate Thumbnails'] = 'Régénérer les miniatures';
$lang['Regenerate Websize Photos'] = 'Régénérer les photos taille web';
$lang['Thumbnails generation in progress...'] = 'Génération des miniatures en cours...';
$lang['Photos generation in progress...'] = 'Génération des photos en cours...';
$lang['%s thumbnails have been regenerated'] = '%s miniatures ont été régénérées';
$lang['%s thumbnails can not be regenerated'] = '%s miniatures ne peuvent pas être régénérées';
$lang['%s photos have been regenerated'] = '%s photos ont été régénérées';
$lang['%s photos can not be regenerated'] = '%s photos ne peuvent pas être régénérées';
$lang['Updates'] = 'Mises à jour';
$lang['Update in progress... Please wait.'] = 'Mise à jour en cours... Veuillez patienter.';
$lang['Ignore this update'] = 'Ignorer cette mise à jour';
$lang['Reset ignored updates'] = 'Réinitialiser les mises à jour ignorées';
$lang['Update All'] = 'Tout mettre à jour';
$lang['ERROR'] = 'ERREUR';
$lang['Update Complete'] = 'Mise à jour effectuée';
$lang['Piwigo Update'] = 'Mise à jour de Piwigo';
$lang['Extensions Update'] = 'Mise à jour des extensions';
$lang['All extensions are up to date.'] = 'Toutes les extensions sont à jour.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Les greffons suivants ne seront peut-être pas compatibles avec la nouvelle version de Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Les thèmes suivants ne seront peut-être pas compatibles avec la nouvelle version de Piwigo:';
$lang['I decide to update anyway'] = 'Je décide de migrer quand même';
$lang['Update to Piwigo %s'] = 'Mettre à jour vers Piwigo %s';
$lang['Two updates are available'] = 'Deux mises à jour sont disponibles';
$lang['This is a minor update, with only bug corrections.'] = 'Ceci est une mise à jour mineure, avec uniquement des corrections de bugs.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Ceci est une mise à jour majeure, qui contient <a href="%s">un tas de nouveautés</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Certains thèmes ou greffons ne sont peut-être pas encore disponibles.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Vous pouvez mettre à jour vers Piwigo %s directement, sans passer par Piwigo %s (recommandé).';
$lang['Save Template Directory'] = 'Sauvegarder le dossier template';
$lang['Dump Database'] = 'Sauvegarder la base de données';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Inclure les données de l\'historique (Attention: risque de dépassement de la limite mémoire du serveur)';
$lang['Unable to write new local directory.'] = 'Impossible d\'écrire le nouveau dossier local.';
$lang['Unable to send template directory.'] = 'Impossible d\'envoyer le dossier template.';
$lang['Unable to dump database.'] = 'Impossible de sauvegarder la base de données.';
$lang['Some upgrades are available for extensions.'] = 'Des mises à jour sont disponibles pour les extensions.';
$lang['Ignore All'] = 'Tout ignorer';
$lang['Crop'] = 'Retailler';
$lang['Width'] = 'Largeur';
$lang['Height'] = 'Hauteur';
$lang['Follow Orientation'] = 'Respecter l\'orientation';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Si vous voulez régénérer des miniatures, merci de vous rendre dans la <a href="%s">Gestion par lot</a>.';
$lang['Graphics Library'] = 'Bibliothèque graphique';
$lang['... or '] = '... ou bien ';
$lang['Create'] = 'Créer';
$lang['Start Upload'] = 'Démarrer le transfert';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Vous utilisez le formulaire Flash. Des problèmes ? Essayez le <a href="%s">formulaire HTML</a> à la place.';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Vous utilisez le formulaire HTML. Essayez le <a href="%s">formulaire Flash</a> à la place.';
$lang['Maximum file size: %sB.'] = 'Poids maximum des fichiers : %sB.';
$lang['Allowed file types: %s.'] = 'Types de fichiers autorisés : %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Résolution maximum approximative : %dM pixels (soit %dx%d pixels).';
$lang['Manage Permissions'] = 'Gérer les permissions';
$lang['Photo %s of %s'] = 'Photo %s sur %s';
$lang['show details'] = 'montrer les détails';
$lang['hide details'] = 'cacher les détails';
$lang['Merge tags'] = 'Fusionner les mots clés';
$lang['Select the destination tag'] = 'Sélectionnez le mot clé de destination';
$lang['(this tag will be deleted)'] = '(ce mot clé sera supprimé)';
$lang['Confirm merge'] = 'Confirmez la fusion';
$lang['Merge selected tags'] = 'Fusionner les mots clés sélectionnés';
$lang['No destination tag selected'] = 'Vous n\'avez pas sélectionné de mot clé de destination';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Les mots clés <em>%s</em> ont été fusionnés dans le mot clé <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Sélectionnez au moins deux mots clés pour la fusion';
$lang['Select an album'] = 'Selectionnez un album';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Par défaut, Piwigo créera la nouvelle taille web à partir de la HD (haute définition).';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Si la HD n\'est pas disponible et que la version actuelle de la taille web est plus grande que les dimensions ci-dessous, alors Piwigo la considérera comme HD et créera la nouvelle taille web à partir de celle-ci.';
$lang['An error has occured during upgrade.'] = 'Une erreur est survenue pendant la mise à jour.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Impossible d\'extraire les fichiers. Veuillez vérifier les permissions des fichiers de votre installation.<br><a href="%s">Cliquez ici pour voir le rapport d\'erreur</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ne peut pas récupérer le fichier de mise à jour depuis le serveur'; 
?>